@@ -58,6 +58,11 @@ def prepare_benchmark_parameters(
                 )
 
             if "ycsb" in benchmark_tool:
+                if isremote is True:
+                    benchmark_tool = (
+                        "/tmp/ycsb-redisearch-binding-0.18.0-SNAPSHOT/bin/ycsb"
+                    )
+                    current_workdir = "/tmp/ycsb-redisearch-binding-0.18.0-SNAPSHOT"
                 command_arr, command_str = prepare_ycsb_benchmark_command(
                     benchmark_tool,
                     server_private_ip,
@@ -122,14 +127,15 @@ def run_remote_benchmark(
         logging.info("remote process stdout: {}".format(stdout))
         logging.info("Extracting the benchmark results")
         remote_run_result = True
-        fetch_file_from_remote_setup(
-            client_public_ip,
-            username,
-            private_key,
-            local_results_file,
-            remote_results_file,
-        )
-    return remote_run_result
+        if "ycsb" not in command:
+            fetch_file_from_remote_setup(
+                client_public_ip,
+                username,
+                private_key,
+                local_results_file,
+                remote_results_file,
+            )
+    return remote_run_result, stdout, stderr
 
 
 def common_exporter_logic(
@@ -169,9 +175,9 @@ def common_exporter_logic(
             test_name,
             tf_triggering_env,
         )
-
-        # push per-branch data
-        push_data_to_redistimeseries(rts, per_version_time_series_dict)
+        if ok:
+            # push per-version data
+            push_data_to_redistimeseries(rts, per_version_time_series_dict)
         if tf_github_branch is not None and tf_github_branch != "":
             # extract per branch datapoints
             ok, per_branch_time_series_dict = extract_perbranch_timeseries_from_results(
@@ -185,8 +191,9 @@ def common_exporter_logic(
                 test_name,
                 tf_triggering_env,
             )
-            # push per-branch data
-            push_data_to_redistimeseries(rts, per_branch_time_series_dict)
+            if ok:
+                # push per-branch data
+                push_data_to_redistimeseries(rts, per_branch_time_series_dict)
         else:
             logging.warning(
                 "Requested to push data to RedisTimeSeries but no git"
